Channel<T> constructor

const Channel<T>(
  1. String name
)

Creates a strongly typed channel using the provided unique string name. This channel instance can later be registered into the Channeler system and then used throughout the application for publishing and subscribing to events associated with this communication topic.

Implementation

const Channel(this.name);