model/ping library

Classes

Ping<T>
This is the class for the ping model here we can define the data it will carry with it so that it will be easier for us to maintain the data object and the specific type of data the pinger will ping to the certain widget in the widget tree. The pinger is a generic class which means it can handle any type of data in the model making it much more easier to maintain a class