data property
T?
data
final
This is the generic data value of the pinger class which held the value from starting to the ending of the ping model
Implementation
final T? data;
This is the generic data value of the pinger class which held the value from starting to the ending of the ping model
final T? data;