name property

String name
final

Define the name for the ping so that you can see it in your logs which pings are being made by the pinger thinking of this as a single generic model in the class which the user can extend to have multiple data model for different case

Implementation

final String name;