pinger library

Classes

Pinger<T>
This is a Pinger for extending the flutter state management for updating the data in the flutter tree with help of the Pinger which will directly can be listened in any ui Widget or any other functionality spots enhancing the speed and communication between tree Widgets.

Typedefs

PingerCallback<T> = void Function(T? value)
The PingerCallback will be used as a data listening port for the other non widget parts so that we can also subscribe to the Pinger updates in any method to directly fetch the update as required.