PingerCallback<T> typedef

PingerCallback<T> = void Function(T? value)

The PingerCallback will be used as a data listening port for the other non widget parts so that we can also subscribe to the Pinger updates in any method to directly fetch the update as required.

Implementation

typedef PingerCallback<T> = void Function(T? value);