create property

T Function() create
final

Factory callback responsible for creating the controller instance when the widget gets inserted into the widget tree during the initialization lifecycle execution phase.

Implementation

final T Function() create;