builder property

Widget Function(BuildContext context, S value) builder
final

A builder function that constructs the UI based on the selected value. This function is only triggered when the selected state changes, which improves performance by preventing unnecessary rebuilds of unchanged UI.

Implementation

final Widget Function(BuildContext context, S value) builder;