selector property

S Function(T controller) selector
final

A selector function that extracts a specific piece of state from the Pingora controller. Only the returned value is monitored for changes, ensuring that the widget rebuilds only when this selected state changes.

Implementation

final S Function(T controller) selector;