initChannel<T> method
Initializes a new communication channel inside the global Channeler infrastructure using the current widget context. Channels must always be initialized before they can receive subscriptions or published events otherwise assertion errors will be triggered during execution.
Implementation
void initChannel<T>(List<Channel<T>> channels) {
channeler.initialize(channels);
}