Ping<T> class
This is the class for the ping model here we can define the data it will carry with it so that it will be easier for us to maintain the data object and the specific type of data the pinger will ping to the certain widget in the widget tree. The pinger is a generic class which means it can handle any type of data in the model making it much more easier to maintain a class
Constructors
Properties
- data → T?
-
This is the generic data value of the pinger class which held the value
from starting to the ending of the ping model
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Define the name for the ping so that you can see it in your logs which
pings are being made by the pinger thinking of this as a single generic
model in the class which the user can extend to have multiple data model
for different case
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited