Ping<T> constructor

Ping<T>({
  1. required String name,
  2. T? data,
})

Constructor of the pinger class for initializing all the required type of the the user requires in the class

Implementation

Ping({required this.name, this.data});