Pinger<T> class
This is a Pinger for extending the flutter state management for updating
the data in the flutter tree with help of the Pinger which will directly
can be listened in any ui Widget or any other functionality spots enhancing
the speed and communication between tree Widgets.
Constructors
- Pinger()
Properties
- data → T?
-
The data will be the Pinger current holding value that can be fetched
when required by the widget and will be updated and sent to multiple
notifiers when ever any update will be received to the Pinger object.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
PingerCallback< T> listener) → void - The dispose function once called will remove all the notifier subscription at once and will disable the notifier functionality after disposing the Pinger any ping to the data will not update any widgets or any subscription
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
ping(
T? data, {bool forcePing = false}) → void -
The ping method checks whether or not the new update contains the
new data and can be updated correctly, you can pass the ping with
forcePingbool value so that if the user wants the updates even if the data is same it can update -
subscribe(
PingerCallback< T?> listener) → void - The subscribe method add the subscription for the current Pinger class when we will subscribe to the current notifier for the updates if you subscribe to the the notifier it is mandatory to unsubscribe from the notifier if you are not disposing the notifier, that will help to unsubscribe single PingerCallback
-
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribe(
PingerCallback< T?> listener) → void - The unsubscribe method removes the subscription for the current Pinger class when we will remove to the current notifier for the updates this will help to remove the unwanted listeners from PingerCallback
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited