dispose method
void
dispose()
Permanently disables this Pingora.
Clears all listeners and sets the disposed flag so that any future calls to subscribe, unsubscribe, or ping will throw an error.
Implementation
void dispose() {
developer.log(
'Pingora<$runtimeType> disposed (listeners cleared: ${_listeners.length})',
name: 'pingora',
);
_disposed = true;
_listeners.clear();
}