pingora/pingora_scope library
Classes
-
PingoraScope<
T extends Pingora> - Widget responsible for automatically creating and disposing a Pingora controller together with the widget lifecycle. This allows developers to scope controllers to a screen, component, or any subtree without manual memory management.
Extensions
- PingoraExtension on BuildContext
- Extension on BuildContext providing convenient access to Pingora controllers that are scoped via PingoraScope ancestors in the widget tree.